@@ -83,19 +83,31 @@ impl From<sqlx_core::error::Error> for crate::Error {
 
 impl From<chrono::ParseError> for crate::Error {
     fn from(arg: ParseError) -> Self {
-        return crate::Error::E(arg.to_string())
+        return crate::Error::E(arg.to_string());
     }
 }
 
 impl From<serde_json::Error> for crate::Error {
     fn from(arg: serde_json::Error) -> Self {
-        return crate::Error::E(arg.to_string())
+        return crate::Error::E(arg.to_string());
     }
 }
 
 impl From<time::ParseError> for crate::Error {
     fn from(arg: time::ParseError) -> Self {
-        return crate::Error::E(arg.to_string())
+        return crate::Error::E(arg.to_string());
+    }
+}
+
+impl From<bson::ser::Error> for crate::Error {
+    fn from(arg: bson::ser::Error) -> Self {
+        return crate::Error::E(arg.to_string());
+    }
+}
+
+impl From<bson::de::Error> for crate::Error {
+    fn from(arg: bson::de::Error) -> Self {
+        return crate::Error::E(arg.to_string());
     }
 }
 
@@ -185,12 +197,6 @@ impl From<Error> for std::io::Error {
     }
 }
 
-impl From<bson::de::Error> for crate::Error {
-    fn from(arg: bson::de::Error) -> Self {
-        Error::E(arg.to_string())
-    }
-}
-
 impl From<ParseBigDecimalError> for crate::Error {
     fn from(arg: ParseBigDecimalError) -> Self {
         Self::E(arg.to_string())
