@@ -33,7 +33,7 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
             "BIGINT UNSIGNED" => {
                 let r: Option<u64> = Decode::<'_, MySql>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(bson!(r as i64));
+                    return Ok(bson!(r));
                 }
                 return Ok(Bson::Null);
             }
@@ -59,14 +59,14 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
             "SMALLINT UNSIGNED" => {
                 let r: Option<u16> = Decode::<'_, MySql>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(bson!(r as i32));
+                    return Ok(bson!(r as u32));
                 }
                 return Ok(Bson::Null);
             }
             "TINYINT UNSIGNED" => {
                 let r: Option<u8> = Decode::<'_, MySql>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(bson!(r as i32));
+                    return Ok(bson!(r as u32));
                 }
                 return Ok(Bson::Null);
             }
