@@ -1,7 +1,5 @@
 use std::ops::{Deref, DerefMut};
-use base64::DecodeError;
-use bson::{Binary, Bson};
-use bson::spec::BinarySubtype;
+use bson::Bson;
 use serde::{Deserializer, Serializer};
 use serde::de::Error;
 
@@ -52,12 +50,14 @@ impl From<&Vec<u8>> for Bytes {
 }
 
 impl serde::Serialize for Bytes {
+    #[inline]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where S: Serializer {
-        return self.inner.serialize(serializer);
+        serializer.serialize_bytes(&self.inner)
     }
 }
 
 impl<'de> serde::Deserialize<'de> for Bytes {
+    #[inline]
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where D: Deserializer<'de> {
         let bson = Bson::deserialize(deserializer)?;
         match bson {
@@ -76,7 +76,7 @@ impl<'de> serde::Deserialize<'de> for Bytes {
                     Err(e) => {
                         return Err(D::Error::custom(e.to_string()));
                     }
-                }
+                };
             }
             _ => {
                 Err(D::Error::custom("deserialize unsupported bson type!"))
@@ -110,13 +110,22 @@ impl DerefMut for Bytes {
 
 #[cfg(test)]
 mod test {
+    use bson::Bson;
     use crate::types::Bytes;
 
     #[test]
     fn test_ser_de() {
         let b = Bytes::from("111".as_bytes());
         let bsons = bson::to_bson(&b).unwrap();
+        match &bsons {
+            bson::Bson::Binary(b) => {
+                assert_eq!(b.subtype, bson::spec::BinarySubtype::Generic);
+                println!("yes is BinarySubtype::Generic");
+            }
+            _ => {}
+        }
         let b_de: Bytes = bson::from_bson(bsons).unwrap();
         assert_eq!(b, b_de);
+        assert_eq!(b.inner, b_de.inner);
     }
 }
\ No newline at end of file
